# 0.0.1  (2021/07/28)  
- Fixed (or tried to) `LICENSE`, `README.md` and `CHANGELOG.md` looks on [pypi.org](https://pypi.org/project/mcwpy/0.0.0/).  

# Initial (2021/07/28)  
- Created two functions to add or substract numbers together.  
- Created a `setup.py` file to setup the library.  
- Wrote `README.md`.  
- Wrote `LICENSE`.  
- Wrote `MANIFEST.md`.  
- Created `REQUIREMENTS.txt`.  
- Created `mcwpy\__init__.py`.  
- Used `python3 setup.py sdist` in a terminal to create the library's first package.  
- Used `twine upload --repository-url https://upload.pypi.org/legacy/ dist/*` to upload the library's first package on pypi.  
